using System;
using System.IO;

namespace Siberix.Examples
{
	class Example
	{
		static void Main(string[] args)
		{
			// Report
			Siberix.Report.Report report = new Siberix.Report.Report();

			// Info
			report.Info.Title = "Example";
			report.Info.Author = "Siberix Technologies, Canada";
			report.Info.Creator = "Siberix Report Writer";
			report.Info.Copyright = "2003-2012 Siberix Technologies, Canada";

			// Section
			Siberix.Report.Section.ISection section = report.AddSection();
			section.Size = new Siberix.Report.PageSize(Siberix.Report.PageSize.Letter.Height / 2, Siberix.Report.PageSize.Letter.Width);
			section.Spacings.Horizontal = 35;
			section.Spacings.Top = 20;
			section.Spacings.Bottom = 5;
			section.Flip = true;

			// Styles
			Siberix.Report.Text.Style style1 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(12), Siberix.Graphics.Brushes.Black);
			Siberix.Report.Text.Style style2 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(12), Siberix.Graphics.Brushes.Red);
			Siberix.Report.Text.Style style3 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(10), Siberix.Graphics.Brushes.Black);

			// Page Numbering
			Siberix.Report.Section.IFooter footer = section.AddFooter();
			footer.Height = new Siberix.Report.DirectHeight(30);

			Siberix.Report.IPageNumber pn = footer.AddPageNumber(20, 5);
			pn.Style = style3;
			pn.Format = Siberix.Report.NumberFormat.Decimal;
			pn.Template = "Page {0} of {1}";
			pn.Alignment = Siberix.Report.NumberAlignment.Left;

			footer = section.AddFooter();
			footer.Height = new Siberix.Report.DirectHeight(30);

			pn = footer.AddPageNumber(375, 5);
			pn.Style = style3;
			pn.Format = Siberix.Report.NumberFormat.Decimal;
			pn.Template = "Page {0} of {1}";
			pn.Alignment = Siberix.Report.NumberAlignment.Right;

			// Content
			for (int i = 1; i < 108; i++)
			{
				Siberix.Report.Text.IText text = section.AddText();
				text.Style = style1;
				text.Spacings.Bottom = 5;
				text.AddContent(i.ToString(), style2);
				text.AddContent(" Amarone is produced in the Veneto region of northern Italy using a unique winemaking technique. Newly harvested grapes are laid on straw mats and left to dry over the course of several months - resulting in a wine with a very distinctive \"raisiny\" flavor.");
			}

			// Booklet
			Siberix.Report.IPageCollection pages = report.Generate();

			Siberix.Report.Report report2 = new Siberix.Report.Report();

			// Section
			section = report2.AddSection();
			section.Size = Siberix.Report.PageSize.Letter;
			section.Orientation = Siberix.Report.Orientation.Landscape;

			int k = 0;
			int cnt = pages.Count - 1;

			MyGraphics graphics = null;

			float midX = Siberix.Report.PageSize.Letter.Height / 2;
			float btmY = Siberix.Report.PageSize.Letter.Width - 10;

			Siberix.Graphics.Pen pen = new Siberix.Graphics.Pen(Siberix.Graphics.Colors.DarkBlue, 0.5F, Graphics.DashStyle.Dash);

			foreach (Siberix.Report.IPage page in pages)
			{
				if ((k % 2) == 0)
				{
					Siberix.Report.ICanvas canvas = section.AddCanvas();

					canvas.Width = new Siberix.Report.RelativeWidth(100);
					canvas.Height = new Siberix.Report.RelativeHeight(100);

					graphics = new MyGraphics(canvas);
				}
				else
				{
					graphics.Translate(Siberix.Report.PageSize.Letter.Height / 2, 0);

					if (k < cnt)
						section.AddPageBreak();
				}

				page.Draw(graphics);

				graphics.Pen = pen;

				graphics.DrawLine(midX, 10, midX, btmY);

				k++;
			}
			
			report2.Publish("Booklet.pdf", Siberix.Report.FileFormat.PDF);

			// View
			System.Diagnostics.Process process = new System.Diagnostics.Process();
			System.Diagnostics.ProcessStartInfo info = new System.Diagnostics.ProcessStartInfo("Booklet.pdf");
			process.StartInfo = info;
			process.Start();
		}
	}

	public class MyGraphics : Siberix.Graphics.IGraphics
	{
		private Siberix.Report.ICanvas _canvas;

		public MyGraphics(Siberix.Report.ICanvas canvas)
		{
			_canvas = canvas;
		}

		public bool AlternateFill
		{
			get
			{
				return _canvas.AlternateFill;
			}
			set
			{
				_canvas.AlternateFill = value;
			}
		}

		public Siberix.Graphics.Brush Brush
		{
			get
			{
				return _canvas.Brush;
			}
			set
			{
				_canvas.Brush = value;
			}
		}

		public float CharSpacing
		{
			get
			{
				return _canvas.CharSpacing;
			}
			set
			{
				_canvas.CharSpacing = value;
			}
		}

		public float CharWidth(char ch)
		{
			return _canvas.CharWidth(ch);
		}

		public void ClipArc(float x, float y, float width, float height, float startAngle, float endAngle)
		{
			_canvas.ClipArc(x, y, width, height, startAngle, endAngle);
		}

		public void ClipBeziers(Siberix.Graphics.PointCollection points)
		{
			_canvas.ClipBeziers(points);
		}

		public void ClipChord(float x, float y, float width, float height, float startAngle, float endAngle)
		{
			_canvas.ClipChord(x, y, width, height, startAngle, endAngle);
		}

		public void ClipClosedCurve(Siberix.Graphics.PointCollection points, float tension)
		{
			_canvas.ClipClosedCurve(points, tension);
		}

		public void ClipEllipse(float x, float y, float width, float height)
		{
			_canvas.ClipEllipse(x, y, width, height);
		}

		public void ClipPie(float x, float y, float width, float height, float startAngle, float endAngle)
		{
			_canvas.ClipPie(x, y, width, height, startAngle, endAngle);
		}

		public void ClipPolygon(Siberix.Graphics.PointCollection points)
		{
			_canvas.ClipPolygon(points);
		}

		public void ClipRectangle(float x, float y, float width, float height)
		{
			_canvas.ClipRectangle(x, y, width, height);
		}

		public void ClipRoundRect(float x, float y, float width, float height, float ew, float eh)
		{
			_canvas.ClipRoundRect(x, y, width, height, ew, eh);
		}

		public void ClosePath()
		{
			_canvas.ClosePath();
		}

		public void CurveTo(float x1, float y1, float x2, float y2, float x3, float y3)
		{
			_canvas.CurveTo(x1, y1, x2, y2, x3, y3);
		}

		public void DrawArc(float x, float y, float width, float height, float startAngle, float endAngle, Siberix.Graphics.PaintMode mode)
		{
			_canvas.DrawArc(x, y, width, height, startAngle, endAngle, mode);
		}

		public void DrawArc(float x, float y, float width, float height, float startAngle, float endAngle)
		{
			_canvas.DrawArc(x, y, width, height, startAngle, endAngle);
		}

		public void DrawBezier(float x1, float y1, float x2, float y2, float x3, float y3, float x4, float y4)
		{
			_canvas.DrawBezier(x1, y1, x2, y2, x3, y3, x4, y4);
		}

		public void DrawBeziers(Siberix.Graphics.PointCollection points, Siberix.Graphics.PaintMode mode)
		{
			_canvas.DrawBeziers(points, mode);
		}

		public void DrawBeziers(Siberix.Graphics.PointCollection points)
		{
			_canvas.DrawBeziers(points);
		}

		public void DrawChord(float x, float y, float width, float height, float startAngle, float endAngle, Siberix.Graphics.PaintMode mode)
		{
			_canvas.DrawChord(x, y, width, height, startAngle, endAngle, mode);
		}

		public void DrawChord(float x, float y, float width, float height, float startAngle, float endAngle)
		{
			_canvas.DrawChord(x, y, width, height, startAngle, endAngle);
		}

		public void DrawClosedCurve(Siberix.Graphics.PointCollection points, float tension, Siberix.Graphics.PaintMode mode)
		{
			_canvas.DrawClosedCurve(points, tension, mode);
		}

		public void DrawClosedCurve(Siberix.Graphics.PointCollection points, float tension)
		{
			_canvas.DrawClosedCurve(points, tension);
		}

		public void DrawCurve(Siberix.Graphics.PointCollection points, float tension)
		{
			_canvas.DrawCurve(points, tension);
		}

		public void DrawEllipse(float x, float y, float width, float height, Siberix.Graphics.PaintMode mode)
		{
			_canvas.DrawEllipse(x, y, width, height, mode);
		}

		public void DrawEllipse(float x, float y, float width, float height)
		{
			_canvas.DrawEllipse(x, y, width, height);
		}

		public void DrawImage(Siberix.Graphics.Image image, float x, float y, float width, float height)
		{
			_canvas.DrawImage(image, x, y, width, height);
		}

		public void DrawLine(float x1, float y1, float x2, float y2)
		{
			_canvas.DrawLine(x1, y1, x2, y2);
		}

		public void DrawLines(Siberix.Graphics.PointCollection points)
		{
			_canvas.DrawLines(points);
		}

		public void DrawPie(float x, float y, float width, float height, float startAngle, float endAngle, Siberix.Graphics.PaintMode mode)
		{
			_canvas.DrawPie(x, y, width, height, startAngle, endAngle, mode);
		}

		public void DrawPie(float x, float y, float width, float height, float startAngle, float endAngle)
		{
			_canvas.DrawPie(x, y, width, height, startAngle, endAngle);
		}

		public void DrawPolygon(Siberix.Graphics.PointCollection points, Siberix.Graphics.PaintMode mode)
		{
			_canvas.DrawPolygon(points, mode);
		}

		public void DrawPolygon(Siberix.Graphics.PointCollection points)
		{
			_canvas.DrawPolygon(points);
		}

		public void DrawRectangle(float x, float y, float width, float height, Siberix.Graphics.PaintMode mode)
		{
			_canvas.DrawRectangle(x, y, width, height, mode);
		}

		public void DrawRectangle(float x, float y, float width, float height)
		{
			_canvas.DrawRectangle(x, y, width, height);
		}

		public void DrawRoundRect(float x, float y, float width, float height, float ew, float eh, Siberix.Graphics.PaintMode mode)
		{
			_canvas.DrawRoundRect(x, y, width, height, ew, eh, mode);
		}

		public void DrawRoundRect(float x, float y, float width, float height, float ew, float eh)
		{
			_canvas.DrawRoundRect(x, y, width, height, ew, eh);
		}

		public void DrawString(float x, float y, string text)
		{
			_canvas.DrawString(x, y, text);
		}

		public void EndHyperlink()
		{
			_canvas.EndHyperlink();
		}

		public void EndShape()
		{
			_canvas.EndShape();
		}

		public void FillArc(float x, float y, float width, float height, float startAngle, float endAngle)
		{
			_canvas.FillArc(x, y, width, height, startAngle, endAngle);
		}

		public void FillBeziers(Siberix.Graphics.PointCollection points)
		{
			_canvas.FillBeziers(points);
		}

		public void FillChord(float x, float y, float width, float height, float startAngle, float endAngle)
		{
			_canvas.FillChord(x, y, width, height, startAngle, endAngle);
		}

		public void FillClosedCurve(Siberix.Graphics.PointCollection points, float tension)
		{
			_canvas.FillClosedCurve(points, tension);
		}

		public void FillEllipse(float x, float y, float width, float height)
		{
			_canvas.FillEllipse(x, y, width, height);
		}

		public void FillPie(float x, float y, float width, float height, float startAngle, float endAngle)
		{
			_canvas.FillPie(x, y, width, height, startAngle, endAngle);
		}

		public void FillPolygon(Siberix.Graphics.PointCollection points)
		{
			_canvas.FillPolygon(points);
		}

		public void FillRectangle(float x, float y, float width, float height)
		{
			_canvas.FillRectangle(x, y, width, height);
		}

		public void FillRoundRect(float x, float y, float width, float height, float ew, float eh)
		{
			_canvas.FillRoundRect(x, y, width, height, ew, eh);
		}

		public void Flush()
		{

		}

		public Siberix.Graphics.Font Font
		{
			get
			{
				return _canvas.Font;
			}
			set
			{
				_canvas.Font = value;
			}
		}

		public Siberix.Graphics.FontMetrics FontMetrics
		{
			get
			{
				return _canvas.FontMetrics;
			}
		}

		public void HyperlinkArea(float x, float y, float width, float height)
		{
			_canvas.HyperlinkArea(x, y, width, height);
		}

		public bool HyperlinkStarted
		{
			get
			{
				return _canvas.HyperlinkStarted;
			}
		}

		public void LineTo(float x, float y)
		{
			_canvas.LineTo(x, y);
		}

		public void MoveTo(float x, float y)
		{
			_canvas.MoveTo(x, y);
		}

		public Siberix.Graphics.Pen Pen
		{
			get
			{
				return _canvas.Pen;
			}
			set
			{
				_canvas.Pen = value;
			}
		}

		public void RestoreClip()
		{
			_canvas.RestoreClip();
		}

		public void RestoreState()
		{
			_canvas.RestoreState();
		}

		public void Rotate(float centerX, float centerY, float angle)
		{
			_canvas.Rotate(centerX, centerY, angle);
		}

		public void SaveClip(float x, float y, float width, float height)
		{
			_canvas.SaveClip(x, y, width, height);
		}

		public void SaveState()
		{
			_canvas.SaveState();
		}

		public void Scale(float scaleX, float scaleY)
		{
			_canvas.Scale(scaleX, scaleY);
		}

		public void Shear(float shearX, float shearY)
		{
			_canvas.Shear(shearX, shearY);
		}

		public void Skew(float skewX, float skewY)
		{
			_canvas.Skew(skewX, skewY);
		}

		public void StartHyperlink(int pageIndex, float x, float y)
		{
			_canvas.StartHyperlink(pageIndex / 2, x, y);
		}

		public void StartHyperlink(string reference)
		{
			_canvas.StartHyperlink(reference);
		}

		public void StartShape(Siberix.Graphics.PaintMode mode)
		{
			_canvas.StartShape(mode);
		}

		public float StringWidth(string text)
		{
			return _canvas.StringWidth(text);
		}

		public void Transform(Siberix.Graphics.Matrix matrix)
		{
			_canvas.Transform(matrix);
		}

		public Siberix.Graphics.Matrix Transformation
		{
			get
			{
				return _canvas.Transformation;
			}
		}

		public void Translate(float offsetX, float offsetY)
		{
			_canvas.Translate(offsetX, offsetY);
		}
	}
}